@@ -1,12 +1,20 @@
-# -------------------------------------------------------------------------
-# Copyright (c) Microsoft Corporation. All rights reserved.
-# Licensed under the MIT License. See License.txt in the project root for
-# license information.
-# --------------------------------------------------------------------------
-from ..common._common_conversion import _to_str
-
-
+﻿#-------------------------------------------------------------------------
+# Copyright (c) Microsoft.  All rights reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#--------------------------------------------------------------------------
+from .._common_conversion import _to_str
 class Share(object):
+
     '''
     File share class.
     
@@ -19,21 +27,17 @@ class Share(object):
         This var is set to None unless the include=metadata param was included 
         for the list shares operation. If this parameter was specified but the 
         share has no metadata, metadata will be set to an empty dictionary.
-    :vartype metadata: dict(str, str)
-    :ivar str snapshot:
-        A DateTime value that uniquely identifies the snapshot. The value of
-        this header indicates the snapshot version, and may be used in
-        subsequent requests to access the snapshot.
+    :vartype metadata: dict mapping str to str
     '''
 
-    def __init__(self, name=None, props=None, metadata=None, snapshot=None):
+    def __init__(self, name=None, props=None, metadata=None):
         self.name = name
         self.properties = props or ShareProperties()
         self.metadata = metadata
-        self.snapshot = snapshot
 
 
 class ShareProperties(object):
+
     '''
     File share's properties class.
     
@@ -51,8 +55,8 @@ class ShareProperties(object):
         self.etag = None
         self.quota = None
 
-
 class Directory(object):
+
     '''
     Directory class.
     
@@ -65,7 +69,7 @@ class Directory(object):
         This var is set to None unless the include=metadata param was included 
         for the list directory operation. If this parameter was specified but the 
         directory has no metadata, metadata will be set to an empty dictionary.
-    :vartype metadata: dict(str, str)
+    :vartype metadata: dict mapping str to str
     '''
 
     def __init__(self, name=None, props=None, metadata=None):
@@ -73,8 +77,8 @@ class Directory(object):
         self.properties = props or DirectoryProperties()
         self.metadata = metadata
 
-
 class DirectoryProperties(object):
+
     '''
     File directory's properties class.
     
@@ -83,17 +87,14 @@ class DirectoryProperties(object):
     :ivar str etag:
         The ETag contains a value that you can use to perform operations
         conditionally.
-    :ivar bool server_encrypted:
-        Set to true if the directory metadata is encrypted on the server.
     '''
 
     def __init__(self):
         self.last_modified = None
         self.etag = None
-        self.server_encrypted = None
-
 
 class File(object):
+
     '''
     File class.
     
@@ -109,7 +110,7 @@ class File(object):
         This var is set to None unless the include=metadata param was included 
         for the list file operation. If this parameter was specified but the 
         file has no metadata, metadata will be set to an empty dictionary.
-    :vartype metadata: dict(str, str)
+    :vartype metadata: dict mapping str to str
     '''
 
     def __init__(self, name=None, content=None, props=None, metadata=None):
@@ -120,6 +121,7 @@ class File(object):
 
 
 class FileProperties(object):
+
     '''
     File Properties.
     
@@ -129,31 +131,23 @@ class FileProperties(object):
         The ETag contains a value that you can use to perform operations
         conditionally.
     :ivar int content_length:
-        The length of the content returned. If the entire blob was requested, 
-        the length of blob in bytes. If a subset of the blob was requested, the 
-        length of the returned subset.
-    :ivar str content_range:
-        Indicates the range of bytes returned in the event that the client 
-        requested a subset of the blob.
+        The size of the file in bytes.
     :ivar ~azure.storage.file.models.ContentSettings content_settings:
         Stores all the content settings for the file.
     :ivar ~azure.storage.file.models.CopyProperties copy:
         Stores all the copy properties for the file.
-    ivar bool server_encrypted:
-        Set to true if the file data and application metadata are completely encrypted.
     '''
 
     def __init__(self):
         self.last_modified = None
         self.etag = None
         self.content_length = None
-        self.content_range = None
         self.content_settings = ContentSettings()
         self.copy = CopyProperties()
-        self.server_encrypted = None
 
 
 class ContentSettings(object):
+
     '''
     Used to store the content settings of a file.
 
@@ -181,9 +175,10 @@ class ContentSettings(object):
     '''
 
     def __init__(
-            self, content_type=None, content_encoding=None,
-            content_language=None, content_disposition=None,
-            cache_control=None, content_md5=None):
+        self, content_type=None, content_encoding=None,
+        content_language=None, content_disposition=None,
+        cache_control=None, content_md5=None):
+        
         self.content_type = content_type
         self.content_encoding = content_encoding
         self.content_language = content_language
@@ -192,14 +187,17 @@ class ContentSettings(object):
         self.content_md5 = content_md5
 
     def _to_headers(self):
-        return {
-            'x-ms-cache-control': _to_str(self.cache_control),
-            'x-ms-content-type': _to_str(self.content_type),
-            'x-ms-content-disposition': _to_str(self.content_disposition),
-            'x-ms-content-md5': _to_str(self.content_md5),
-            'x-ms-content-encoding': _to_str(self.content_encoding),
-            'x-ms-content-language': _to_str(self.content_language),
-        }
+        return [
+            ('x-ms-cache-control', _to_str(self.cache_control)),
+            ('x-ms-content-type', _to_str(self.content_type)),
+            ('x-ms-content-disposition',
+                _to_str(self.content_disposition)),
+            ('x-ms-content-md5', _to_str(self.content_md5)),
+            ('x-ms-content-encoding',
+                _to_str(self.content_encoding)),
+            ('x-ms-content-language',
+                _to_str(self.content_language)),
+        ]
 
 
 class CopyProperties(object):
@@ -224,7 +222,7 @@ class CopyProperties(object):
                 Copy completed successfully.
             pending: 
                 Copy is in progress. Check copy_status_description if intermittent,
-                non-fatal errors impede copy progress but don't cause failure.
+                non-fatal errors impede copy progress but don’t cause failure.
             aborted:
                 Copy was ended by Abort Copy File.
             failed:
@@ -252,6 +250,7 @@ class CopyProperties(object):
 
 
 class FileRange(object):
+
     '''
     File Range.
     
@@ -266,18 +265,8 @@ class FileRange(object):
         self.end = end
 
 
-class DeleteSnapshot(object):
-    '''
-    Required if the Share has associated snapshots. Specifies how to handle the snapshots.
-    '''
-
-    Include = 'include'
-    '''
-    Delete the share and all of its snapshots.
-    '''
-
-
 class FilePermissions(object):
+
     '''
     FilePermissions class to be used with 
     :func:`~azure.storage.file.fileservice.FileService.generate_file_shared_access_signature` API.
@@ -293,8 +282,7 @@ class FilePermissions(object):
         Create or write content, properties, metadata. Resize the file. Use the file 
         as the destination of a copy operation within the same account.
     '''
-
-    def __init__(self, read=False, create=False, write=False, delete=False,
+    def __init__(self, read=False, create=False, write=False, delete=False, 
                  _str=None):
         '''
         :param bool read:
@@ -317,13 +305,13 @@ class FilePermissions(object):
         self.create = create or ('c' in _str)
         self.write = write or ('w' in _str)
         self.delete = delete or ('d' in _str)
-
+    
     def __or__(self, other):
         return FilePermissions(_str=str(self) + str(other))
 
     def __add__(self, other):
         return FilePermissions(_str=str(self) + str(other))
-
+    
     def __str__(self):
         return (('r' if self.read else '') +
                 ('c' if self.create else '') +
@@ -338,6 +326,7 @@ FilePermissions.WRITE = FilePermissions(write=True)
 
 
 class SharePermissions(object):
+
     '''
     SharePermissions class to be used with `azure.storage.file.FileService.generate_share_shared_access_signature`
     method and for the AccessPolicies used with `azure.storage.file.FileService.set_share_acl`. 
@@ -358,8 +347,7 @@ class SharePermissions(object):
         Note: You cannot grant permissions to read or write share properties or 
         metadata with a service SAS. Use an account SAS instead.
     '''
-
-    def __init__(self, read=False, write=False, delete=False, list=False,
+    def __init__(self, read=False, write=False, delete=False, list=False, 
                  _str=None):
         '''
         :param bool read:
@@ -387,21 +375,20 @@ class SharePermissions(object):
         self.write = write or ('w' in _str)
         self.delete = delete or ('d' in _str)
         self.list = list or ('l' in _str)
-
+    
     def __or__(self, other):
         return SharePermissions(_str=str(self) + str(other))
 
     def __add__(self, other):
         return SharePermissions(_str=str(self) + str(other))
-
+    
     def __str__(self):
         return (('r' if self.read else '') +
                 ('w' if self.write else '') +
-                ('d' if self.delete else '') +
+                ('d' if self.delete else '') + 
                 ('l' if self.list else ''))
 
-
 SharePermissions.DELETE = SharePermissions(delete=True)
 SharePermissions.LIST = SharePermissions(list=True)
 SharePermissions.READ = SharePermissions(read=True)
-SharePermissions.WRITE = SharePermissions(write=True)
+SharePermissions.WRITE = SharePermissions(write=True)
\ No newline at end of file
