@@ -1,7 +1,16 @@
 # -------------------------------------------------------------------------
-# Copyright (c) Microsoft Corporation. All rights reserved.
-# Licensed under the MIT License. See License.txt in the project root for
-# license information.
+# Copyright (c) Microsoft.  All rights reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 # --------------------------------------------------------------------------
 from ..common._common_conversion import _to_str
 
@@ -39,10 +48,6 @@ class ContainerProperties(object):
         conditionally.
     :ivar LeaseProperties lease:
         Stores all the lease information for the container.
-    :ivar bool has_immutability_policy:
-        Represents whether the container has an immutability policy.
-    :ivar bool has_legal_hold:
-        Represents whether the container has a legal hold.
     '''
 
     def __init__(self):
@@ -50,8 +55,6 @@ class ContainerProperties(object):
         self.etag = None
         self.lease = LeaseProperties()
         self.public_access = None
-        self.has_immutability_policy = None
-        self.has_legal_hold = None
 
 
 class Blob(object):
@@ -71,20 +74,14 @@ class Blob(object):
         Stores all the system properties for the blob.
     :ivar metadata:
         Name-value pairs associated with the blob as metadata.
-    :ivar bool deleted:
-        Specify whether the blob was soft deleted.
-        In other words, if the blob is being retained by the delete retention policy,
-        this field would be True. The blob could be undeleted or it will be garbage collected after the specified
-        time period.
     '''
 
-    def __init__(self, name=None, snapshot=None, content=None, props=None, metadata=None, deleted=False):
+    def __init__(self, name=None, snapshot=None, content=None, props=None, metadata=None):
         self.name = name
         self.snapshot = snapshot
         self.content = content
         self.properties = props or BlobProperties()
         self.metadata = metadata
-        self.deleted = deleted
 
 
 class BlobProperties(object):
@@ -130,12 +127,6 @@ class BlobProperties(object):
     :ivar bool blob_tier_inferred:
         Indicates whether the access tier was inferred by the service.
         If false, it indicates that the tier was set explicitly.
-    :ivar datetime deleted_time:
-        A datetime object representing the time at which the blob was deleted.
-    :ivar int remaining_retention_days:
-        The number of days that the blob will be retained before being permanently deleted by the service.
-    :ivar datetime creation_time:
-        Indicates when the blob was created, in UTC.
     '''
 
     def __init__(self):
@@ -153,9 +144,6 @@ class BlobProperties(object):
         self.blob_tier = None
         self.blob_tier_change_time = None
         self.blob_tier_inferred = False
-        self.deleted_time = None
-        self.remaining_retention_days = None
-        self.creation_time = None
 
 
 class ContentSettings(object):
@@ -527,12 +515,10 @@ class Include(object):
     :ivar ~azure.storage.blob.models.Include Include.UNCOMMITTED_BLOBS: 
         Specifies that blobs for which blocks have been uploaded, but which have not 
         been committed using Put Block List, be included in the response.
-    :ivar ~azure.storage.blob.models.Include Include.DELETED:
-        Specifies that deleted blobs should be returned in the response.
     '''
 
     def __init__(self, snapshots=False, metadata=False, uncommitted_blobs=False,
-                 copy=False, deleted=False, _str=None):
+                 copy=False, _str=None):
         '''
         :param bool snapshots:
              Specifies that snapshots should be included in the enumeration.
@@ -543,9 +529,7 @@ class Include(object):
             not been committed using Put Block List, be included in the response.
         :param bool copy: 
             Specifies that metadata related to any current or previous Copy Blob 
-            operation should be included in the response.
-        :param bool deleted:
-            Specifies that deleted blobs should be returned in the response.
+            operation should be included in the response. 
         :param str _str: 
             A string representing the includes.
         '''
@@ -556,7 +540,6 @@ class Include(object):
         self.metadata = metadata or ('metadata' in components)
         self.uncommitted_blobs = uncommitted_blobs or ('uncommittedblobs' in components)
         self.copy = copy or ('copy' in components)
-        self.deleted = deleted or ('deleted' in components)
 
     def __or__(self, other):
         return Include(_str=str(self) + str(other))
@@ -568,8 +551,7 @@ class Include(object):
         include = (('snapshots,' if self.snapshots else '') +
                    ('metadata,' if self.metadata else '') +
                    ('uncommittedblobs,' if self.uncommitted_blobs else '') +
-                   ('copy,' if self.copy else '') +
-                   ('deleted,' if self.deleted else ''))
+                   ('copy,' if self.copy else ''))
         return include.rstrip(',')
 
 
@@ -577,7 +559,6 @@ Include.COPY = Include(copy=True)
 Include.METADATA = Include(metadata=True)
 Include.SNAPSHOTS = Include(snapshots=True)
 Include.UNCOMMITTED_BLOBS = Include(uncommitted_blobs=True)
-Include.DELETED = Include(deleted=True)
 
 
 class BlobPermissions(object):
@@ -669,19 +650,13 @@ class ContainerPermissions(object):
         a container SAS. Use an account SAS instead.
     '''
 
-    def __init__(self, read=False, add=False, create=False, write=False, delete=False, list=False,
+    def __init__(self, read=False, write=False, delete=False, list=False,
                  _str=None):
         '''
         :param bool read:
             Read the content, properties, metadata or block list of any blob in the 
             container. Use any blob in the container as the source of a copy operation.
-        :param bool add:
-            Add a block to any append blob in the container.
-        :param bool create:
-            Write a new blob to the container, snapshot any blob in the container, or copy a blob to
-            a new blob in the container. Note: You cannot grant permissions to create a container
-            with a container SAS. Use an account SAS to create a container instead.
-        :param bool write:
+        :param bool write: 
             For any blob in the container, create or write content, properties, 
             metadata, or block list. Snapshot or lease the blob. Resize the blob 
             (page blob only). Use the blob as the destination of a copy operation 
@@ -699,8 +674,6 @@ class ContainerPermissions(object):
         if not _str:
             _str = ''
         self.read = read or ('r' in _str)
-        self.add = add or ('a' in _str)
-        self.create = create or ('c' in _str)
         self.write = write or ('w' in _str)
         self.delete = delete or ('d' in _str)
         self.list = list or ('l' in _str)
@@ -713,8 +686,6 @@ class ContainerPermissions(object):
 
     def __str__(self):
         return (('r' if self.read else '') +
-                ('a' if self.add else '') +
-                ('c' if self.create else '') +
                 ('w' if self.write else '') +
                 ('d' if self.delete else '') +
                 ('l' if self.list else ''))
@@ -724,8 +695,6 @@ ContainerPermissions.DELETE = ContainerPermissions(delete=True)
 ContainerPermissions.LIST = ContainerPermissions(list=True)
 ContainerPermissions.READ = ContainerPermissions(read=True)
 ContainerPermissions.WRITE = ContainerPermissions(write=True)
-ContainerPermissions.ADD = ContainerPermissions(add=True)
-ContainerPermissions.CREATE = ContainerPermissions(create=True)
 
 
 class PremiumPageBlobTier(object):
@@ -774,52 +743,3 @@ class StandardBlobTier(object):
 
     Hot = 'Hot'
     ''' Hot '''
-
-
-class AccountInformation(object):
-    """
-    Holds information related to the storage account.
-
-    :ivar str sku_name:
-        Name of the storage SKU, also known as account type.
-        Example: Standard_LRS, Standard_ZRS, Standard_GRS, Standard_RAGRS, Premium_LRS, Premium_ZRS
-    :ivar str account_kind:
-        Describes the flavour of the storage account, also known as account kind.
-        Example: Storage, StorageV2, BlobStorage
-    """
-    def __init__(self):
-        self.sku_name = None
-        self.account_kind = None
-
-
-class UserDelegationKey(object):
-    """
-    Represents a user delegation key, provided to the user by Azure Storage
-    based on their Azure Active Directory access token.
-
-    The fields are saved as simple strings since the user does not have to interact with this object;
-    to generate an identify SAS, the user can simply pass it to the right API.
-
-    :ivar str signed_oid:
-        Object ID of this token.
-    :ivar str signed_tid:
-        Tenant ID of the tenant that issued this token.
-    :ivar str signed_start:
-        The datetime this token becomes valid.
-    :ivar str signed_expiry:
-        The datetime this token expires.
-    :ivar str signed_service:
-        What service this key is valid for.
-    :ivar str signed_version:
-        The version identifier of the REST service that created this token.
-    :ivar str value:
-        The user delegation key.
-    """
-    def __init__(self):
-        self.signed_oid = None
-        self.signed_tid = None
-        self.signed_start = None
-        self.signed_expiry = None
-        self.signed_service = None
-        self.signed_version = None
-        self.value = None
