@@ -3,10 +3,12 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
+# pylint: disable=docstring-keyword-should-match-keyword-only
 
 from typing import (  # pylint: disable=unused-import
     Union, Optional, Any, List, TYPE_CHECKING
 )
+from urllib.parse import parse_qs
 
 from ._shared import sign_string
 from ._shared.constants import X_MS_VERSION
@@ -16,7 +18,7 @@ from ._shared.parser import _str
 
 if TYPE_CHECKING:
     from datetime import datetime
-    from .import (
+    from azure.storage.fileshare import (
         ResourceTypes,
         AccountSasPermissions,
         ShareSasPermissions,
@@ -75,9 +77,8 @@ class FileSharedAccessSignature(SharedAccessSignature):
         :param start:
             The time at which the shared access signature becomes valid. If
             omitted, start time for this call is assumed to be the time when the
-            storage service receives the request. Azure will always convert values
-            to UTC. If a date is passed in without timezone info, it is assumed to
-            be UTC.
+            storage service receives the request. The provided datetime will always
+            be interpreted as UTC.
         :type start: datetime or str
         :param str policy_id:
             A unique value up to 64 characters in length that correlates to a
@@ -107,6 +108,8 @@ class FileSharedAccessSignature(SharedAccessSignature):
         :param str content_type:
             Response header value for Content-Type when resource is accessed
             using this shared access signature.
+        :returns: The generated SAS token for the account.
+        :rtype: str
         '''
         resource_path = share_name
         if directory_name is not None:
@@ -154,9 +157,8 @@ class FileSharedAccessSignature(SharedAccessSignature):
         :param start:
             The time at which the shared access signature becomes valid. If
             omitted, start time for this call is assumed to be the time when the
-            storage service receives the request. Azure will always convert values
-            to UTC. If a date is passed in without timezone info, it is assumed to
-            be UTC.
+            storage service receives the request. The provided datetime will always
+            be interpreted as UTC.
         :type start: datetime or str
         :param str policy_id:
             A unique value up to 64 characters in length that correlates to a
@@ -186,6 +188,8 @@ class FileSharedAccessSignature(SharedAccessSignature):
         :param str content_type:
             Response header value for Content-Type when resource is accessed
             using this shared access signature.
+        :returns: The generated SAS token for the account.
+        :rtype: str
         '''
         sas = _FileSharedAccessHelper()
         sas.add_base(permission, expiry, start, ip, protocol, self.x_ms_version)
@@ -237,16 +241,17 @@ class _FileSharedAccessHelper(_SharedAccessHelper):
 
 
 def generate_account_sas(
-        account_name,  # type: str
-        account_key,  # type: str
-        resource_types,  # type: Union[ResourceTypes, str]
-        permission,  # type: Union[AccountSasPermissions, str]
-        expiry,  # type: Optional[Union[datetime, str]]
-        start=None,  # type: Optional[Union[datetime, str]]
-        ip=None,  # type: Optional[str]
-        **kwargs  # type: Any
-    ):
-    # type: (...) -> str
+    account_name: str,
+    account_key: str,
+    resource_types: Union["ResourceTypes", str],
+    permission: Union["AccountSasPermissions", str],
+    expiry: Union["datetime", str],
+    start: Optional[Union["datetime", str]] = None,
+    ip: Optional[str] = None,
+    *,
+    services: Union[Services, str] = Services(fileshare=True),
+    **kwargs: Any
+) -> str:
     """Generates a shared access signature for the file service.
 
     Use the returned signature with the credential parameter of any ShareServiceClient,
@@ -261,23 +266,15 @@ def generate_account_sas(
     :param ~azure.storage.fileshare.AccountSasPermissions permission:
         The permissions associated with the shared access signature. The
         user is restricted to operations allowed by the permissions.
-        Required unless an id is given referencing a stored access policy
-        which contains this field. This field must be omitted if it has been
-        specified in an associated stored access policy.
     :param expiry:
         The time at which the shared access signature becomes invalid.
-        Required unless an id is given referencing a stored access policy
-        which contains this field. This field must be omitted if it has
-        been specified in an associated stored access policy. Azure will always
-        convert values to UTC. If a date is passed in without timezone info, it
-        is assumed to be UTC.
+        The provided datetime will always be interpreted as UTC.
     :type expiry: ~datetime.datetime or str
     :param start:
         The time at which the shared access signature becomes valid. If
         omitted, start time for this call is assumed to be the time when the
-        storage service receives the request. Azure will always convert values
-        to UTC. If a date is passed in without timezone info, it is assumed to
-        be UTC.
+        storage service receives the request. The provided datetime will always
+        be interpreted as UTC.
     :type start: ~datetime.datetime or str
     :param str ip:
         Specifies an IP address or a range of IP addresses from which to accept requests.
@@ -285,6 +282,9 @@ def generate_account_sas(
         or address range specified on the SAS token, the request is not authenticated.
         For example, specifying sip=168.1.5.65 or sip=168.1.5.60-168.1.5.70 on the SAS
         restricts the request to those IP addresses.
+    :keyword Union[Services, str] services:
+        Specifies the services that the Shared Access Signature (sas) token will be able to be utilized with.
+        Will default to only this package (i.e. fileshare) if not provided.
     :keyword str protocol:
         Specifies the protocol permitted for a request made. The default value is https.
     :return: A Shared Access Signature (sas) token.
@@ -301,7 +301,7 @@ def generate_account_sas(
     """
     sas = SharedAccessSignature(account_name, account_key)
     return sas.generate_account(
-        services=Services(fileshare=True),
+        services=services,
         resource_types=resource_types,
         permission=permission,
         expiry=expiry,
@@ -312,16 +312,16 @@ def generate_account_sas(
 
 
 def generate_share_sas(
-        account_name,  # type: str
-        share_name,  # type: str
-        account_key,  # type: str
-        permission=None,  # type: Optional[Union[ShareSasPermissions, str]]
-        expiry=None,  # type: Optional[Union[datetime, str]]
-        start=None,  # type: Optional[Union[datetime, str]]
-        policy_id=None,  # type: Optional[str]
-        ip=None,  # type: Optional[str]
-        **kwargs # type: Any
-    ):  # type: (...) -> str
+    account_name,  # type: str
+    share_name,  # type: str
+    account_key,  # type: str
+    permission=None,  # type: Optional[Union[ShareSasPermissions, str]]
+    expiry=None,  # type: Optional[Union[datetime, str]]
+    start=None,  # type: Optional[Union[datetime, str]]
+    policy_id=None,  # type: Optional[str]
+    ip=None,  # type: Optional[str]
+    **kwargs # type: Any
+):  # type: (...) -> str
     """Generates a shared access signature for a share.
 
     Use the returned signature with the credential parameter of any ShareServiceClient,
@@ -340,7 +340,7 @@ def generate_share_sas(
         Required unless an id is given referencing a stored access policy
         which contains this field. This field must be omitted if it has been
         specified in an associated stored access policy.
-    :type permission: str or ShareSasPermissions
+    :type permission: str or ~azure.storage.fileshare.ShareSasPermissions
     :param expiry:
         The time at which the shared access signature becomes invalid.
         Required unless an id is given referencing a stored access policy
@@ -352,9 +352,8 @@ def generate_share_sas(
     :param start:
         The time at which the shared access signature becomes valid. If
         omitted, start time for this call is assumed to be the time when the
-        storage service receives the request. Azure will always convert values
-        to UTC. If a date is passed in without timezone info, it is assumed to
-        be UTC.
+        storage service receives the request. The provided datetime will always
+        be interpreted as UTC.
     :type start: ~datetime.datetime or str
     :param str policy_id:
         A unique value up to 64 characters in length that correlates to a
@@ -386,6 +385,11 @@ def generate_share_sas(
     :return: A Shared Access Signature (sas) token.
     :rtype: str
     """
+    if not policy_id:
+        if not expiry:
+            raise ValueError("'expiry' parameter must be provided when not using a stored access policy.")
+        if not permission:
+            raise ValueError("'permission' parameter must be provided when not using a stored access policy.")
     sas = FileSharedAccessSignature(account_name, account_key)
     return sas.generate_share(
         share_name=share_name,
@@ -399,17 +403,17 @@ def generate_share_sas(
 
 
 def generate_file_sas(
-        account_name,  # type: str
-        share_name,  # type: str
-        file_path,  # type: List[str]
-        account_key,  # type: str
-        permission=None,  # type: Optional[Union[FileSasPermissions, str]]
-        expiry=None,  # type: Optional[Union[datetime, str]]
-        start=None,  # type: Optional[Union[datetime, str]]
-        policy_id=None,  # type: Optional[str]
-        ip=None,  # type: Optional[str]
-        **kwargs # type: Any
-    ):
+    account_name,  # type: str
+    share_name,  # type: str
+    file_path,  # type: List[str]
+    account_key,  # type: str
+    permission=None,  # type: Optional[Union[FileSasPermissions, str]]
+    expiry=None,  # type: Optional[Union[datetime, str]]
+    start=None,  # type: Optional[Union[datetime, str]]
+    policy_id=None,  # type: Optional[str]
+    ip=None,  # type: Optional[str]
+    **kwargs # type: Any
+):
     # type: (...) -> str
     """Generates a shared access signature for a file.
 
@@ -432,7 +436,7 @@ def generate_file_sas(
         Required unless an id is given referencing a stored access policy
         which contains this field. This field must be omitted if it has been
         specified in an associated stored access policy.
-    :type permission: str or FileSasPermissions
+    :type permission: str or ~azure.storage.fileshare.FileSasPermissions
     :param expiry:
         The time at which the shared access signature becomes invalid.
         Required unless an id is given referencing a stored access policy
@@ -444,9 +448,8 @@ def generate_file_sas(
     :param start:
         The time at which the shared access signature becomes valid. If
         omitted, start time for this call is assumed to be the time when the
-        storage service receives the request. Azure will always convert values
-        to UTC. If a date is passed in without timezone info, it is assumed to
-        be UTC.
+        storage service receives the request. The provided datetime will always
+        be interpreted as UTC.
     :type start: ~datetime.datetime or str
     :param str policy_id:
         A unique value up to 64 characters in length that correlates to a
@@ -477,6 +480,11 @@ def generate_file_sas(
     :return: A Shared Access Signature (sas) token.
     :rtype: str
     """
+    if not policy_id:
+        if not expiry:
+            raise ValueError("'expiry' parameter must be provided when not using a stored access policy.")
+        if not permission:
+            raise ValueError("'permission' parameter must be provided when not using a stored access policy.")
     sas = FileSharedAccessSignature(account_name, account_key)
     if len(file_path) > 1:
         dir_path = '/'.join(file_path[:-1])
@@ -493,3 +501,13 @@ def generate_file_sas(
         ip=ip,
         **kwargs
     )
+
+def _is_credential_sastoken(credential: Any) -> bool:
+    if not credential or not isinstance(credential, str):
+        return False
+
+    sas_values = QueryStringConstants.to_list()
+    parsed_query = parse_qs(credential.lstrip("?"))
+    if parsed_query and all(k in sas_values for k in parsed_query):
+        return True
+    return False
